@@ -197,6 +197,8 @@ static double GetEdgeBackgroundCensus(const Image *image,
       break;
     }
   }
+  if (p == (const Quantum *) NULL)
+    return(0.0);
   GetPixelInfoPixel(image,p,&background);
   artifact=GetImageArtifact(image,"background");
   if (artifact != (const char *) NULL)
@@ -274,7 +276,7 @@ static RectangleInfo GetEdgeBoundingBox(const Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   SetGeometry(image,&bounds);
   edge_image=CloneImage(image,0,0,MagickTrue,exception);
@@ -413,7 +415,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   artifact=GetImageArtifact(image,"trim:percent-background");
   if (artifact != (const char *) NULL)
@@ -792,7 +794,7 @@ MagickExport PointInfo *GetImageConvexHull(const Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   *number_vertices=0;
   vertices_info=AcquireVirtualMemory(image->columns,image->rows*
@@ -908,7 +910,7 @@ MagickExport size_t GetImageDepth(const Image *image,ExceptionInfo *exception)
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   number_threads=(size_t) GetMagickResourceLimit(ThreadResource);
   current_depth=(size_t *) AcquireQuantumMemory(number_threads,
@@ -1225,7 +1227,7 @@ MagickExport PointInfo *GetImageMinimumBoundingBox(Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   *number_vertices=0;
   vertices=GetImageConvexHull(image,&number_hull_vertices,exception);
@@ -1578,7 +1580,7 @@ MagickExport ImageType IdentifyImageGray(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (IsImageGray(image) != MagickFalse)
     return(image->type);
@@ -1659,7 +1661,7 @@ MagickExport MagickBooleanType IdentifyImageMonochrome(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->type == BilevelType)
     return(MagickTrue);
@@ -1728,7 +1730,7 @@ MagickExport ImageType IdentifyImageType(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->colorspace == CMYKColorspace)
     {
@@ -1861,7 +1863,7 @@ MagickExport MagickBooleanType IsImageOpaque(const Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->alpha_trait == UndefinedPixelTrait)
     return(MagickTrue);
@@ -1929,7 +1931,7 @@ MagickExport MagickBooleanType SetImageDepth(Image *image,
     y;
 
   assert(image != (Image *) NULL);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(image->signature == MagickCoreSignature);
   if (depth >= MAGICKCORE_QUANTUM_DEPTH)
@@ -2145,7 +2147,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
     *quantize_info;
 
   assert(image != (Image *) NULL);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(image->signature == MagickCoreSignature);
   status=MagickTrue;
@@ -2160,6 +2162,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
     {
       status=TransformImageColorspace(image,GRAYColorspace,exception);
       (void) NormalizeImage(image,exception);
+      (void) BilevelImage(image,(double) QuantumRange/2.0,exception);
       quantize_info=AcquireQuantizeInfo(image_info);
       quantize_info->number_colors=2;
       quantize_info->colorspace=GRAYColorspace;
